@@ -41,21 +41,24 @@ import mslib.msui.wms_control as wc
 
 
 class HSecViewMockup(mock.Mock):
-    getCRS = mock.Mock(return_value="EPSG:4326")
+    get_crs = mock.Mock(return_value="EPSG:4326")
     getBBOX = mock.Mock(return_value=(0, 0, 10, 10))
-    getPlotSizePx = mock.Mock(return_value=(200, 100))
+    get_plot_size_in_px = mock.Mock(return_value=(200, 100))
 
 
 class VSecViewMockup(mock.Mock):
-    getCRS = mock.Mock(return_value="VERT:LOGP")
+    get_crs = mock.Mock(return_value="VERT:LOGP")
     getBBOX = mock.Mock(return_value=(3, 500, 3, 10))
-    getPlotSizePx = mock.Mock(return_value=(200, 100))
+    get_plot_size_in_px = mock.Mock(return_value=(200, 100))
 
 
-class Test_HSecWMSControlWidget(object):
-    def setup(self):
+class WMSControlWidgetSetup(object):
+    def _setup(self, widget_type):
         self.application = QtWidgets.QApplication(sys.argv)
-        self.view = HSecViewMockup()
+        if widget_type == "hsec":
+            self.view = HSecViewMockup()
+        else:
+            self.view = VSecViewMockup()
         self.tempdir = tempfile.mkdtemp()
         if not os.path.exists(self.tempdir):
             os.mkdir(self.tempdir)
@@ -66,7 +69,14 @@ class Test_HSecWMSControlWidget(object):
             args=(mslib.mswms.wms.application,),
             kwargs={"host": "127.0.0.1", "port": "8082", "use_threadpool": False})
         self.thread.start()
-        self.window = wc.HSecWMSControlWidget(view=self.view, wms_cache=self.tempdir)
+        if widget_type == "hsec":
+            self.window = wc.HSecWMSControlWidget(view=self.view, wms_cache=self.tempdir)
+        else:
+            initial_waypoints = [ft.Waypoint(40., 25., 0), ft.Waypoint(60., -10., 0), ft.Waypoint(40., 10, 0)]
+            waypoints_model = ft.WaypointsTableModel("")
+            waypoints_model.insertRows(0, rows=len(initial_waypoints), waypoints=initial_waypoints)
+            self.window = wc.VSecWMSControlWidget(
+                view=self.view, wms_cache=self.tempdir, waypoints_model=waypoints_model)
         self.window.show()
         QtWidgets.QApplication.processEvents()
         QtTest.QTest.qWait(2000)
@@ -88,9 +98,17 @@ class Test_HSecWMSControlWidget(object):
             QtWidgets.QApplication.processEvents()
         QtTest.QTest.keyClicks(self.window.cbWMS_URL, url)
         QtWidgets.QApplication.processEvents()
+        QtTest.QTest.qWait(2000)  # time for the server to start up
+        QtWidgets.QApplication.processEvents()
         QtTest.QTest.mouseClick(self.window.btGetCapabilities, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
-        QtTest.QTest.qWait(2000)
+        QtTest.QTest.qWait(3000)  # time for the server to parse all netcdf data
+        QtWidgets.QApplication.processEvents()
+
+
+class Test_HSecWMSControlWidget(WMSControlWidgetSetup):
+    def setup(self):
+        self._setup("hsec")
 
     @mock.patch("mslib.msui.mss_qt.QtWidgets.QMessageBox")
     def test_no_server(self, mockbox):
@@ -139,7 +157,6 @@ class Test_HSecWMSControlWidget(object):
         assert that an aborted getmap call does not change the displayed image
         """
         self.query_server("http://127.0.0.1:8082")
-
         QtTest.QTest.mouseClick(self.window.btGetMap, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
         QtTest.QTest.qWait(20)
@@ -147,9 +164,9 @@ class Test_HSecWMSControlWidget(object):
         QtWidgets.QApplication.processEvents()
         QtTest.QTest.qWait(2000)
 
-        assert self.view.drawImage.call_count == 0
-        assert self.view.drawLegend.call_count == 0
-        assert self.view.drawMetadata.call_count == 0
+        assert self.view.draw_image.call_count == 0
+        assert self.view.draw_legend.call_count == 0
+        assert self.view.draw_metadata.call_count == 0
         self.view.reset_mock()
 
     @mock.patch("mslib.msui.mss_qt.QtWidgets.QMessageBox")
@@ -161,12 +178,14 @@ class Test_HSecWMSControlWidget(object):
 
         QtTest.QTest.mouseClick(self.window.btGetMap, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
-        QtTest.QTest.qWait(3000)
+        QtTest.QTest.qWait(1000)
+        QtWidgets.QApplication.processEvents()
+        QtTest.QTest.qWait(6000)
         assert mockbox.critical.call_count == 0
 
-        assert self.view.drawImage.call_count == 1
-        assert self.view.drawLegend.call_count == 1
-        assert self.view.drawMetadata.call_count == 1
+        assert self.view.draw_image.call_count == 1
+        assert self.view.draw_legend.call_count == 1
+        assert self.view.draw_metadata.call_count == 1
         self.view.reset_mock()
 
     @mock.patch("mslib.msui.mss_qt.QtWidgets.QMessageBox")
@@ -178,12 +197,16 @@ class Test_HSecWMSControlWidget(object):
 
         QtTest.QTest.mouseClick(self.window.btGetMap, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
-        QtTest.QTest.qWait(2000)
+        QtTest.QTest.qWait(1000)
+        QtWidgets.QApplication.processEvents()
+        QtTest.QTest.qWait(6000)
+        QtWidgets.QApplication.processEvents()
+
         assert mockbox.critical.call_count == 0
 
-        assert self.view.drawImage.call_count == 1
-        assert self.view.drawLegend.call_count == 1
-        assert self.view.drawMetadata.call_count == 1
+        assert self.view.draw_image.call_count == 1
+        assert self.view.draw_legend.call_count == 1
+        assert self.view.draw_metadata.call_count == 1
         self.view.reset_mock()
 
         QtTest.QTest.mouseClick(self.window.cbCacheEnabled, QtCore.Qt.LeftButton)
@@ -191,11 +214,14 @@ class Test_HSecWMSControlWidget(object):
         QtTest.QTest.mouseClick(self.window.btGetMap, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
         QtTest.QTest.qWait(1000)
+        QtWidgets.QApplication.processEvents()
+        QtTest.QTest.qWait(1000)
+
         assert mockbox.critical.call_count == 0
 
-        assert self.view.drawImage.call_count == 1
-        assert self.view.drawLegend.call_count == 1
-        assert self.view.drawMetadata.call_count == 1
+        assert self.view.draw_image.call_count == 1
+        assert self.view.draw_legend.call_count == 1
+        assert self.view.draw_metadata.call_count == 1
 
     @mock.patch("mslib.msui.mss_qt.QtWidgets.QMessageBox")
     def test_server_service_cache(self, mockbox):
@@ -211,9 +237,9 @@ class Test_HSecWMSControlWidget(object):
         QtTest.QTest.mouseClick(self.window.btGetCapabilities, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
         assert mockbox.critical.call_count == 1
-        assert self.view.drawImage.call_count == 0
-        assert self.view.drawLegend.call_count == 0
-        assert self.view.drawMetadata.call_count == 0
+        assert self.view.draw_image.call_count == 0
+        assert self.view.draw_legend.call_count == 0
+        assert self.view.draw_metadata.call_count == 0
         mockbox.reset_mock()
 
         QtTest.QTest.keyClick(self.window.cbWMS_URL, QtCore.Qt.Key_2)
@@ -224,58 +250,19 @@ class Test_HSecWMSControlWidget(object):
 
         QtTest.QTest.mouseClick(self.window.btGetMap, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
-        QtTest.QTest.qWait(2000)
+        QtTest.QTest.qWait(1000)
+        QtWidgets.QApplication.processEvents()
+        QtTest.QTest.qWait(6000)
 
         assert mockbox.critical.call_count == 0
-        assert self.view.drawImage.call_count == 1
-        assert self.view.drawLegend.call_count == 1
-        assert self.view.drawMetadata.call_count == 1
+        assert self.view.draw_image.call_count == 1
+        assert self.view.draw_legend.call_count == 1
+        assert self.view.draw_metadata.call_count == 1
 
 
-class Test_VSecWMSControlWidget(object):
+class Test_VSecWMSControlWidget(WMSControlWidgetSetup):
     def setup(self):
-        self.application = QtWidgets.QApplication(sys.argv)
-        self.view = VSecViewMockup()
-        self.tempdir = tempfile.mkdtemp()
-        if not os.path.exists(self.tempdir):
-            os.mkdir(self.tempdir)
-        paste.httpserver.ServerExit()
-        QtTest.QTest.qWait(2000)
-        self.thread = multiprocessing.Process(
-            target=paste.httpserver.serve,
-            args=(mslib.mswms.wms.application,),
-            kwargs={"host": "127.0.0.1", "port": "8082", "use_threadpool": False})
-        self.thread.start()
-
-        initial_waypoints = [ft.Waypoint(40., 25., 0), ft.Waypoint(60., -10., 0), ft.Waypoint(40., 10, 0)]
-        waypoints_model = ft.WaypointsTableModel("")
-        waypoints_model.insertRows(
-            0, rows=len(initial_waypoints), waypoints=initial_waypoints)
-        self.window = wc.VSecWMSControlWidget(
-            view=self.view, wms_cache=self.tempdir, waypoints_model=waypoints_model)
-        self.window.show()
-
-        QtWidgets.QApplication.processEvents()
-        QtTest.QTest.qWait(2000)
-        QtTest.QTest.qWaitForWindowExposed(self.window)
-        QtTest.QTest.mouseClick(self.window.cbCacheEnabled, QtCore.Qt.LeftButton)
-        QtWidgets.QApplication.processEvents()
-
-    def teardown(self):
-        self.window.hide()
-        QtWidgets.QApplication.processEvents()
-        self.application.quit()
-        QtWidgets.QApplication.processEvents()
-        shutil.rmtree(self.tempdir)
-        self.thread.terminate()
-
-    def query_server(self, url):
-        QtWidgets.QApplication.processEvents()
-        QtTest.QTest.keyClicks(self.window.cbWMS_URL, url)
-        QtWidgets.QApplication.processEvents()
-        QtTest.QTest.mouseClick(self.window.btGetCapabilities, QtCore.Qt.LeftButton)
-        QtWidgets.QApplication.processEvents()
-        QtTest.QTest.qWait(2000)
+        self._setup("vsec")
 
     @mock.patch("mslib.msui.mss_qt.QtWidgets.QMessageBox")
     def test_server_getmap(self, mockbox):
@@ -285,10 +272,12 @@ class Test_VSecWMSControlWidget(object):
         self.query_server("http://127.0.0.1:8082")
         QtTest.QTest.mouseClick(self.window.btGetMap, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
-        QtTest.QTest.qWait(2000)
+        QtTest.QTest.qWait(1000)
+        QtWidgets.QApplication.processEvents()
+        QtTest.QTest.qWait(6000)
 
         assert mockbox.critical.call_count == 0
-        assert self.view.drawImage.call_count == 1
-        assert self.view.drawLegend.call_count == 1
-        assert self.view.drawMetadata.call_count == 1
+        assert self.view.draw_image.call_count == 1
+        assert self.view.draw_legend.call_count == 1
+        assert self.view.draw_metadata.call_count == 1
         self.view.reset_mock()
