@@ -39,8 +39,8 @@ surface_geopotential
 m2.s-2
   2.12e+03   4.74e+03
 air_pressure_at_sea_level
-hPa
-  9.89e+02   5.30e+03
+Pa
+  9.89e+04   5.30e+02
 total_cloud_cover
 (0.-.1)
   6.32e-01   3.93e-01
@@ -83,25 +83,25 @@ vertically_integrated_probability_of_wcb_occurrence
 
 _PROFILES_TEXT = """\
 air_pressure
-hPa
-  20         2
-  30         3
-  50         5
-  70         7
-  100       10
-  150       15
-  200       20
-  250       25
-  300       30
-  400       40
-  500       50
-  600       60
-  700       70
-  800       80
-  850       85
-  900       90
-  925       95
-  950       100
+Pa
+  2000         200
+  3000         300
+  5000         500
+  7000         700
+  10000       1000
+  15000       1500
+  20000       2000
+  25000       2500
+  30000       3000
+  40000       4000
+  50000       5000
+  60000       6000
+  70000       7000
+  80000       8000
+  85000       8500
+  90000       9000
+  92500       9500
+  95000       10000
 ertel_potential_vorticity
 PVU
   1.04e+02   2.25e+01
@@ -242,7 +242,7 @@ kg.kg-1
   5.16e-03   2.37e-03
   5.64e-03   2.44e-03
   6.07e-03   2.55e-03
-omega
+lagrangian_tendency_of_air_pressure
 Pa.s-1
  -2.45e-04   5.71e-03
  -4.91e-04   7.48e-03
@@ -567,7 +567,7 @@ _ALLOW_NEGATIVE = ['surface_geopotential',
                    'ertel_potential_vorticity',
                    'eastward_wind',
                    'northward_wind',
-                   'omega',
+                   'lagrangian_tendency_of_air_pressure',
                    'divergence_of_wind']
 
 
@@ -587,6 +587,7 @@ def _parse_text(text, entry_length):
         result[name] = {"unit": unit, "data": data}
     return result
 
+
 _PROFILES = _parse_text(_PROFILES_TEXT, 20)
 _SURFACE = _parse_text(_SURFACE_TEXT, 3)
 
@@ -698,9 +699,8 @@ class DataFiles(object):
         "time": ("time", "hours since 2012-10-17T12:00:00.000Z", "")
     }
 
-    def __init__(self, data_dir=None, vt_cache=None, server_config_dir=None):
+    def __init__(self, data_dir=None, server_config_dir=None):
         self.data_dir = data_dir
-        self.vt_cache = vt_cache
         self.server_config_file = os.path.join(server_config_dir, "mss_wms_settings.py")
         self.server_auth_config_file = os.path.join(server_config_dir, "mss_wms_auth.py")
         # define file dimension / geographical  range
@@ -832,16 +832,13 @@ import mslib.mswms
 #base_dir = os.path.abspath(os.path.dirname(mslib.mswms.__file__))
 #xml_template_location = os.path.join(base_dir, "xml_templates")
 
-
-_vt_cache = r"{vt_cache}"
-mslib.mswms.dataaccess.valid_time_cache = _vt_cache
-
 _datapath = r"{data_dir}"
 
-nwpaccess = {{
-    "ecmwf_EUR_LL015": mslib.mswms.dataaccess.ECMWFDataAccess(_datapath, "EUR_LL015"),
+data = {{
+   "ecmwf_EUR_LL015": mslib.mswms.dataaccess.DefaultDataAccess(_datapath, "EUR_LL015"),
 }}
 
+
 epsg_to_mpl_basemap_table = {{
     # EPSG:4326, the standard cylindrical lat/lon projection.
     4326: {{"projection": "cyl"}}
@@ -888,15 +885,15 @@ if mpl_vsec_styles is not None:
         (mpl_vsec_styles.VS_TemperatureStyle_01, ["ecmwf_EUR_LL015"])
     ]
 '''
-            simple_server_config = simple_server_config.format(vt_cache=self.vt_cache,
-                                                               data_dir=self.data_dir)
+            simple_server_config = simple_server_config.format(data_dir=self.data_dir)
         else:
             simple_server_config = '''"""
 simple server config for demodata
 """
-from mslib.mswms.demodata import (nwpaccess, epsg_to_mpl_basemap_table,
+from mslib.mswms.demodata import (data, epsg_to_mpl_basemap_table,
                                   register_horizontal_layers, register_vertical_layers)
 '''
+
         if not os.path.exists(self.server_config_file):
             fid = open(self.server_config_file, 'w')
             fid.write(simple_server_config)
@@ -950,7 +947,7 @@ from mslib.mswms.demodata import (nwpaccess, epsg_to_mpl_basemap_table,
                 newvar = ecmwf.createVariable('hyam', 'f4', 'hybrid')
                 newvar[:] = get_profile("hybrid", values, "atmosphere_hybrid_pressure_coordinate")[0]
                 newvar.units = 'Pa'
-                newvar.standard_name = "atmosphere_pressure_coordinate"
+                newvar.standard_name = "atmosphere_hybrid_pressure_coordinate"
                 newvar = ecmwf.createVariable('hybm', 'f4', 'hybrid')
                 newvar[:] = get_profile("hybrid", values, "atmosphere_hybrid_height_coordinate")[0]
                 newvar.units = '1'
@@ -987,7 +984,7 @@ from mslib.mswms.demodata import (nwpaccess, epsg_to_mpl_basemap_table,
         """
         Method to generate all required model data for testing purposes.
         """
-        times, lats, lons = np.arange(0, 39, 3), np.arange(70, 30, -1), np.arange(0, 50)
+        times, lats, lons = np.arange(0, 39, 6), np.arange(70, 30, -1), np.arange(-50, 50)
 
         for coordinate, label, levtype, coord_levels, variables in (
                 ("air_pressure", "PRESSURE_LEVELS", "pl",
@@ -995,15 +992,15 @@ from mslib.mswms.demodata import (nwpaccess, epsg_to_mpl_basemap_table,
                   np.array([30, 50, 70, 100, 150, 200, 250, 300, 400, 500, 600, 700, 800, 900])),
                  ["air_potential_temperature", "air_pressure", "air_temperature",
                   "eastward_wind", "ertel_potential_vorticity", "geopotential_height",
-                  "northward_wind", "specific_humidity", "omega", "divergence_of_wind",
+                  "northward_wind", "specific_humidity", "lagrangian_tendency_of_air_pressure", "divergence_of_wind",
                   "mass_fraction_of_ozone_in_air", "mole_fraction_of_ozone_in_air", "equivalent_latitude",
                   "number_of_wcb_trajectories", "number_of_insitu_trajectories", "number_of_mix_trajectories"]),
 
                 ("ertel_potential_vorticity", "PVU", "pv",
-                 ("atmosphere_ertel_potential_vorticity_coordinate", [2, 3, 4]),
+                 ("atmosphere_ertel_potential_vorticity_coordinate", [2, 2.5, 3, 3.5, 4]),
                  ["air_potential_temperature", "geopotential_height", "air_pressure"]),
 
-                ("geopotential_height", "ALTITUDE_LEVELS", "ml",
+                ("geopotential_height", "ALTITUDE_LEVELS", "al",
                  ("atmosphere_altitude_coordinate", np.arange(5000, 15001, 500)),
                  ["air_pressure", "ertel_potential_vorticity", "mole_fraction_of_ozone_in_air"]),
 
@@ -1025,15 +1022,17 @@ from mslib.mswms.demodata import (nwpaccess, epsg_to_mpl_basemap_table,
                 ("T", "air_temperature"),
                 ("U", "eastward_wind"),
                 ("V", "northward_wind"),
-                ("W", "omega"),
+                ("W", "lagrangian_tendency_of_air_pressure"),
                 ("Q", "specific_humidity")):
             self.generate_file(
                 "hybrid", varname, "ml",
-                (("time", times), ("hybrid", np.arange(0, 19)), ("latitude", lats), ("longitude", lons)),
+                (("time", times), ("hybrid", np.arange(0, 18)), ("latitude", lats), ("longitude", lons)),
                 [standard_name])
 
         self.generate_file(
-            None, "SFC", "sfc", (("time", times), ("latitude", lats), ("longitude", lons)), list(_SURFACE.keys()))
+            None, "SFC", "sfc", (("time", times), ("latitude", lats), ("longitude", lons)),
+            [_x for _x in _SURFACE.keys() if _x not in [
+                "vertically_integrated_probability_of_wcb_occurrence", "solar_elevation_angle"]])
         self.generate_file(
             None, "ProbWCB_LAGRANTO_derived", "sfc", (("time", times), ("latitude", lats), ("longitude", lons)),
             ["vertically_integrated_probability_of_wcb_occurrence"])
@@ -1046,12 +1045,12 @@ def main():
     creates various test data files and also the server configuration
     """
     examples = DataFiles(data_dir=os.path.join(os.path.expanduser("~"), "mss", 'testdata'),
-                         vt_cache=os.path.join(os.path.expanduser("~"), "mss", "vt_cache"),
                          server_config_dir=os.path.join(os.path.expanduser("~"), "mss"))
     examples.create_datadir()
     examples.create_server_config(detailed_information=True)
     examples.create_data()
     print("\nTo use this setup you need the mss_wms_settings.py in your python path e.g. \nexport PYTHONPATH=~/mss")
 
+
 if __name__ == '__main__':
     main()
