@@ -109,8 +109,8 @@ class MSSPlotDriver(with_metaclass(ABCMeta, object)):
         fc_step = fc_time - init_time
         fc_step = fc_step.days * 24 + (fc_step.seconds // 3600)
         self.fc_time = fc_time
-        logging.debug(u"\trequested initialisation time {}".format(init_time))
-        logging.debug(u"\trequested forecast valid time {} (step {} hrs)".format(fc_time, fc_step))
+        logging.debug(u"\trequested initialisation time %s", init_time)
+        logging.debug(u"\trequested forecast valid time %s (step %s hrs)", fc_time, fc_step)
 
         # Check if a dataset is open and if it contains the requested times.
         # (a dataset will only be open if the used layer has not changed,
@@ -118,9 +118,9 @@ class MSSPlotDriver(with_metaclass(ABCMeta, object)):
         if self.dataset is not None:
             logging.debug("checking on open dataset.")
             if self.init_time == init_time:
-                logging.debug(u"\tinitialisation time ok ({}).".format(init_time))
+                logging.debug(u"\tinitialisation time ok (%s).", init_time)
                 if fc_time in self.times:
-                    logging.debug(u"\tforecast valid time contained ({}).".format(fc_time))
+                    logging.debug(u"\tforecast valid time contained (%s).", fc_time)
                     return
             logging.debug("need to re-open input files.")
             self.dataset.close()
@@ -142,10 +142,10 @@ class MSSPlotDriver(with_metaclass(ABCMeta, object)):
             short_filename = os.path.basename(filename)
             if filename not in filenames:
                 filenames.append(filename)
-            logging.debug(u"\tvariable '{}' requires input file '{}'".format(var, short_filename))
+            logging.debug(u"\tvariable '%s' requires input file '%s'", var, short_filename)
             if short_filename not in available_files:
-                logging.error(u"ERROR: file '{}' does not exist".format(short_filename))
-                raise IOError(u"file '{}' does not exist".format(short_filename))
+                logging.error(u"ERROR: file '%s' does not exist", short_filename)
+                raise IOError(u"file '%s' does not exist", short_filename)
 
         if len(filenames) == 0:
             raise ValueError("no files found that correspond to the specified "
@@ -169,74 +169,29 @@ class MSSPlotDriver(with_metaclass(ABCMeta, object)):
         #     raise ValueError("wrong initialisation time in input")
 
         if fc_time not in times:
-            msg = u"Forecast valid time {} is not available.".format(fc_time)
+            msg = u"Forecast valid time '{}' is not available.".format(fc_time)
             logging.error(msg)
             dataset.close()
             raise ValueError(msg)
 
         # Load lat/lon dimensions.
         try:
-            lat_data, lon_data, lat_order = \
-                netCDF4tools.get_latlon_data(dataset)
+            lat_data, lon_data, lat_order = netCDF4tools.get_latlon_data(dataset)
         except Exception as ex:
-            logging.error("ERROR: {} {}".format(type(ex), ex))
+            logging.error(u"ERROR: %s %s", type(ex), ex)
             dataset.close()
             raise
 
-        # Try to load vertical hybrid coordinate (model levels), isopressure
-        # coordinate (pressure levels) or iso-potential-vorticity (pv levels).
-        # NOTE: This code assumes that a file contains data on exactly one level
-        # type, not on more that one!
-        vert_data = None
-        vert_orientation = None
-        vert_units = None
+        _, vert_data, vert_orientation, vert_units, _ = netCDF4tools.identify_vertical_axis(dataset)
+        self.vert_data = vert_data[:] if vert_data is not None else None
+        self.vert_order = vert_orientation
+        self.vert_units = vert_units
 
-        hybrid_name, hybrid_var, hybrid_orientation = \
-            netCDF4tools.identify_CF_hybrid(dataset)
-        if hybrid_var is not None:
-            vert_data = hybrid_var[:]
-            vert_orientation = hybrid_orientation
-            vert_units = "model_level"
-
-        if vert_data is None:
-            isopressure_name, isopressure_var, isopressure_orientation = \
-                netCDF4tools.identify_CF_isopressure(dataset)
-            if isopressure_var is not None:
-                vert_data = isopressure_var[:]
-                vert_orientation = isopressure_orientation
-                vert_units = "hPa"
-
-        if vert_data is None:
-            isopotvort_name, isopotvort_var, isopotvort_orientation = \
-                netCDF4tools.identify_CF_isopotvort(dataset)
-            if isopotvort_var is not None:
-                vert_data = isopotvort_var[:]
-                vert_orientation = isopotvort_orientation
-                vert_units = "10^-3 PVU"
-
-        if vert_data is None:
-            isoalt_name, isoalt_var, isoalt_orientation = \
-                netCDF4tools.identify_CF_isoaltitude(dataset)
-            if isoalt_var is not None:
-                vert_data = isoalt_var[:]
-                vert_orientation = isoalt_orientation
-                vert_units = isoalt_var.units
-
-        if vert_data is None:
-            isoalt_name, isoalt_var, isoalt_orientation = \
-                netCDF4tools.identify_CF_isopottemp(dataset)
-            if isoalt_var is not None:
-                vert_data = isoalt_var[:]
-                vert_orientation = isoalt_orientation
-                vert_units = isoalt_var.units
         self.dataset = dataset
         self.times = times
         self.lat_data = lat_data
         self.lon_data = lon_data
         self.lat_order = lat_order
-        self.vert_data = vert_data
-        self.vert_order = vert_orientation
-        self.vert_units = vert_units
 
         # Identify the variable objects from the NetCDF file that correspond
         # to the data fields required by the plot object.
@@ -252,10 +207,12 @@ class MSSPlotDriver(with_metaclass(ABCMeta, object)):
         <data_vars> can be accessed as <self.data_vars>.
         """
         self.data_vars = {}
+        self.data_units = {}
         for df_type, df_name in self.plot_object.required_datafields:
             varname, var = netCDF4tools.identify_variable(self.dataset, df_name, check=True)
-            logging.debug("\tidentified variable <{}> for field <{}>".format(varname, df_name))
+            logging.debug("\tidentified variable <%s> for field <%s>", varname, df_name)
             self.data_vars[df_name] = var
+            self.data_units[df_name] = getattr(var, "units", None)
 
     @abstractmethod
     def set_plot_parameters(self, plot_object, init_time=None, valid_time=None,
@@ -272,8 +229,8 @@ class MSSPlotDriver(with_metaclass(ABCMeta, object)):
         Derived methods need to call the super method before all other
         statements.
         """
-        logging.debug("using plot object '{}'".format(plot_object.name))
-        logging.debug("\tfigure size {} in pixels".format(figsize))
+        logging.debug("using plot object '%s'", plot_object.name)
+        logging.debug("\tfigure size %s in pixels", figsize)
 
         # If the plot object has been changed, the dataset needs to be reloaded
         # (the required variables could have changed).
@@ -426,8 +383,8 @@ class VerticalSectionDriver(MSSPlotDriver):
                                    vsec_path_connection='linear'):
         """
         """
-        logging.debug("computing {:} interpolation points, connection: {}"
-                      .format(vsec_numpoints, vsec_path_connection))
+        logging.debug("computing %i interpolation points, connection: %s",
+                      vsec_numpoints, vsec_path_connection)
         now = datetime.now()
         self.lats, self.lons, _ = utils.path_points(
             [(_x, _y, now) for _x, _y in vsec_path],
@@ -452,16 +409,17 @@ class VerticalSectionDriver(MSSPlotDriver):
         if self.dataset is None:
             return {}
         data = {}
+
         timestep = self.times.searchsorted(self.fc_time)
-        logging.debug("loading data for time step {} ({})".format(timestep, self.fc_time))
+        logging.debug("loading data for time step %s (%s)", timestep, self.fc_time)
 
         # Determine the westmost longitude in the cross-section path. Subtract
         # one gridbox size to obtain "left_longitude".
         dlon = self.lon_data[1] - self.lon_data[0]
         left_longitude = self.lons.min() - dlon
         logging.debug("shifting data grid to gridpoint west of westmost "
-                      "longitude in path: {:.2f} (path {:.2f}).."
-                      .format(left_longitude, self.lons.min()))
+                      "longitude in path: %.2f (path %.2f).",
+                      left_longitude, self.lons.min())
 
         # Shift the longitude field such that the data is in the range
         # left_longitude .. left_longitude+360.
@@ -477,10 +435,10 @@ class VerticalSectionDriver(MSSPlotDriver):
                 var_data = var[timestep, ::-self.vert_order, ::self.lat_order, :]
             else:
                 var_data = var[:][timestep, np.newaxis, ::self.lat_order, :]
-            logging.debug("\tLoaded {:.2f} Mbytes from data field <{:}> at timestep {:}.".format(
-                          (var_data.nbytes / 1048576.), name, timestep))
-            logging.debug("\tVertical dimension direction is {}.".format(
-                          "up" if self.vert_order == 1 else "down"))
+            logging.debug("\tLoaded %.2f Mbytes from data field <%s> at timestep %s.",
+                          var_data.nbytes / 1048576., name, timestep)
+            logging.debug("\tVertical dimension direction is %s.",
+                          "up" if self.vert_order == 1 else "down")
             logging.debug("\tInterpolating to cross-section path.")
             # Re-arange longitude dimension in the data field.
             var_data = var_data[:, :, lon_indices]
@@ -504,7 +462,7 @@ class VerticalSectionDriver(MSSPlotDriver):
         # Determine the leftmost longitude in the plot.
         left_longitude = self.lons.min()
         logging.debug(u"shifting data grid to leftmost longitude in path "
-                      u"({:.2f})..".format(left_longitude))
+                      u"(%.2f)..", left_longitude)
 
         # Shift the longitude field such that the data is in the range
         # left_longitude .. left_longitude+360.
@@ -528,7 +486,7 @@ class VerticalSectionDriver(MSSPlotDriver):
         data = self._load_interpolate_timestep()
 
         d2 = datetime.now()
-        logging.debug("Loaded and interpolated data (required time {}).".format(d2 - d1))
+        logging.debug("Loaded and interpolated data (required time %s).", d2 - d1)
         logging.debug("Plotting interpolated curtain.")
 
         if len(self.lat_data) > 1 and len(self.lon_data) > 1:
@@ -555,8 +513,8 @@ class VerticalSectionDriver(MSSPlotDriver):
         del data
 
         d3 = datetime.now()
-        logging.debug("Finished plotting (required time {}; total "
-                      "time {}).\n".format(d3 - d2, d3 - d1))
+        logging.debug("Finished plotting (required time %s; total "
+                      "time %s).\n", d3 - d2, d3 - d1)
 
         return image
 
@@ -629,12 +587,13 @@ class HorizontalSectionDriver(MSSPlotDriver):
         timestep = self.times.searchsorted(self.fc_time)
         level = None
         if self.level is not None:
-            level = self.vert_data[::self.vert_order].searchsorted(self.level)
-            if self.vert_order == -1:
-                level = len(self.vert_data) - 1 - level
+            # select the nearest level available
+            level = np.abs(self.vert_data - self.level).argmin()
+            if abs(self.vert_data[level] - self.level) > 1e-3 * np.abs(np.diff(self.vert_data).mean()):
+                raise ValueError("Requested elevation not available.")
             self.actual_level = self.vert_data[level]
-        logging.debug("loading data for time step {} ({}), level index {} (level {})".format(
-                      timestep, self.fc_time, level, self.level))
+        logging.debug("loading data for time step %s (%s), level index %s (level %s)",
+                      timestep, self.fc_time, level, self.actual_level)
         for name, var in list(self.data_vars.items()):
             if level is None or len(var.shape) == 3:
                 # 2D fields: time, lat, lon.
@@ -642,8 +601,8 @@ class HorizontalSectionDriver(MSSPlotDriver):
             else:
                 # 3D fields: time, level, lat, lon.
                 var_data = var[timestep, level, ::self.lat_order, :]
-            logging.debug("\tLoaded {:.2f} Mbytes from data field <{}>."
-                          .format(var_data.nbytes / 1048576., name))
+            logging.debug("\tLoaded %.2f Mbytes from data field <%s>.",
+                          var_data.nbytes / 1048576., name)
             data[name] = var_data
             # Free memory.
             del var_data
@@ -662,7 +621,7 @@ class HorizontalSectionDriver(MSSPlotDriver):
         data = self._load_timestep()
 
         d2 = datetime.now()
-        logging.debug("Loaded data (required time %s)." % (d2 - d1))
+        logging.debug("Loaded data (required time %s).", (d2 - d1))
         logging.debug("Plotting horizontal section.")
 
         if len(self.lat_data) > 1:
@@ -689,7 +648,7 @@ class HorizontalSectionDriver(MSSPlotDriver):
         del data
 
         d3 = datetime.now()
-        logging.debug("Finished plotting (required time {}; total "
-                      "time {}).\n".format(d3 - d2, d3 - d1))
+        logging.debug("Finished plotting (required time %s; total "
+                      "time %s).\n", d3 - d2, d3 - d1)
 
         return image
